STWCS
-----

`STWCS <http://ssb.stsci.edu/doc/stsci_python_dev/stwcs.doc/html/index.html>`__ provides support for WCS distortion models and coordinate
transformation for the imaging instruments on the Hubble Space Telescope (HST).


Installation
------------

To clone the project from github::

    git clone https://github.com/spacetelescope/stwcs.git

To install::

    python setup.py install